#
# Copyright (C) 2017-2023 Red Hat, Inc.
#
# Cockpit is free software; you can redistribute it and/or modify it
# under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation; either version 2.1 of the License, or
# (at your option) any later version.
#
# Cockpit is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Cockpit; If not, see <http://www.gnu.org/licenses/>.
#

Name: cockpit-session-recording
Version: 16
Release: 1.0.1%{?dist}
Summary: Cockpit Session Recording
License: LGPL-2.1-or-later
URL:     https://github.com/Scribery/%{name}
Source:  https://github.com/Scribery/%{name}/releases/download/%{version}/%{name}-%{version}.tar.xz

Patch1001: 1001-Make-per-page-documentation-links-point-to-Oracle-Li.patch

BuildArch: noarch
BuildRequires: nodejs
BuildRequires: make
BuildRequires: libappstream-glib
BuildRequires: gettext
%if 0%{?rhel} && 0%{?rhel} <= 8
BuildRequires: libappstream-glib-devel
%endif
Requires: cockpit-system
Requires: tlog
Requires: sssd-proxy

%description
Cockpit module providing session recording configuration and playback.
This module allows viewing and playback of journal-stored terminal session
recordings generated by the tlog component.

%prep
%setup -qn cockpit-session-recording
patch -p 1 -T < %{P:1001}

%install
%make_install PREFIX=/usr
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*

%files
%{_datadir}/cockpit/session-recording
%{_datadir}/metainfo/org.cockpit-project.session-recording.metainfo.xml

%changelog
* Tue Apr 09 2024 EL Errata <el-errata_ww@oracle.com> - 16-1.0.1
- Make per page documentation links point to Oracle Linux [Orabug: 32013095]

* Thu Feb 8 2024 Justin Stephenson <jstephen@redhat.com> - 16-1
- Rebase to upstream release 16
- Config: Add sssd-proxy requirement
- Commits from release 15
- Config: Update to authselect with-tlog feature
- stylelint: handle stylelint-scss deprecation
- Add ruff configuration
- package.json: drop flowtype plugin
- package.json: drop po2json
- package.json: document the required nodejs version
- fmf: Plumb through $TEST_* variables for unexpected messages
- tests: Use mc for testPlayBinary
- package.json: drop deprecated eslint-plugin-standard
- Revert "build: add support for /pybridge scenario"
- Player: Stop making the Terminal object state
- build.js: support flags
- packaging: Update spec License: to SPDX format
- build.js: Fix LINT env variable check
- Tests: Allow charset journal messages
- Update to the new root creation function
- package.json: Bump stylelint to 15
- test: add check for sssd config id_provider proxy
- Tests: Allow invalid non-UTF8 journal messages
- Add xterm-canvas-addon dependency for rendering
- Minor Eslint fixes
- Tests: Update data list to PF5 for testAppMenu
- Update org.cockpit-project.session-recording.metainfo.xml
- Makefile: bump our test/common dependency
- patternfly-5-overrides should be auto-imported by the page.scss file
- Drop obsolete pf-m-redhat-font class
- Commits from release 14
- Upgrade to PatternFly 5 Alpha
- Makefile: Update Cockpit lib to da5abbb4245b0455cc8b610efe01e684
- package.json: Pin down versions of @patternfly/react-{styles,icons}
- Makefile: Update Cockpit lib to 947f1753867e3924b9617aaace936225
- Makefile: Fix watch dependencies
- Update release.yml
- Automate the release process

* Tue May 2 2023 Justin Stephenson <jstephen@redhat.com> - 13-1
- Play after rewind in testFastforwardControls
- Set TZ to avoid CI failures with testFilter* tests
- testZoomSpeedControls incorrectly checks scale
- Fix testSessionRecordingConf
- Read TMT_TEST_DATA variable for LOGS in browser.sh
- Fix node-modules in run-test.sh
- Install sssd-proxy in test browser.sh
- Add Files path for test recordings
- FMF: Run tests together
- Add executable bit to browser shell scripts
- FMF: Fix minor typo in plans
- Add FMF tests and test scripts
- Read existing sssd conf domains and services
- Makefile: Update Cockpit lib to 269bf89276c679a03befc8a04244addd
- Remove CentOS condition in testZoomSpeedControls
- Add accessible name label for Progress component
- Remove 'enable_files_domain' from SSSD Config
- SSSD config changes
- testFastforwardControls update after player-restart
- Switch wait_present to wait_visible
- ESLint error and warning fixes
- Fix stylelint errors
- Dependency updates
- Bring up to date with cockpit starter kit
- Config: Switch SSSD files provider to Proxy provider
- Update fedora license in spec file
- Makefile: Bump test API to 267
- Makefile: drop installing cockpit-ws/cockpit-packagekit
- src: load translations via po.js
- .semaphore: update TEST_OS to Fedora 36
- webpack.config.js: update compression plugin to succeed build
- Makefile: Adjust to changed rpmspec -q behaviour
- Use standard "translate" marker in HTML
- Update dependencies excluding Patternfly
- Remove unneeded tlog UID code

* Wed Jun 8 2022 Justin Stephenson <jstephen@redhat.com> - 12-2
- Tests: Remove usermod from browser setup

* Mon May 23 2022 Justin Stephenson <jstephen@redhat.com> - 12-1
- Drop moment.js dependency
- Tests: Assert pause state with a later command in rec1
- CI: Update image to ubuntu 20.04

* Thu Nov 18 2021 Justin Stephenson <jstephen@redhat.com> - 11-2
- Workaround cockpit-ws selinux guestfs issue

* Wed Nov 17 2021 Justin Stephenson <jstephen@redhat.com> - 11-1
- Avoid crash in unmount if journal is null
- Sync Makefile closer to starter-kit
- Use current babel/eslint integration
- Use Flex layout for spacing the two config cards in the config page
- Use Page/PageSection/Breadcrumb patternfly components
- Move to xz dist tarballs
- Remove unused slider.html file
- package.json: explicitely depend on @patternfly/react-icons
- webpack: Use relative resolve path for npm 7 compatibility
- package.json: update patternfly packages
- package.json: use sass instead of node-sass
- Fetch pkg/lib automatically from cockpit instead of keeping a local copy
- Update Docker image and TEST_OS run to Fedora 35
- Tests: Test SSSD exclude_users and exclude_groups
- Config: Add SSSD exclude_users and exclude_groups
- TESTS: Fix testSessionRecordingConf cleanup issue
- TESTS: Restart SSSD after restoring config

* Wed Nov 17 2021 Justin Stephenson <jstephen@redhat.com> - 9-1
- Release v9
- Tests: Fix RHEL9 filter test timing failures

* Wed Nov 17 2021 Justin Stephenson <jstephen@redhat.com> - 8-1
- Release v8
- Throttle journalctl restarts
- Minor CI fixes

* Tue Apr 27 2021 Justin Stephenson <jstephen@redhat.com> - 7-1
- Remove bots sudo rm from Makefile
- Use journalctl --utc for Logs view to handle DST
- Add Applications Menu test
- Install cockpit-packagekit in local VM
- Set timezone for Logs Correlation test

* Wed Nov 4 2020 Justin Stephenson <jstephen@redhat.com> - 6-2
- Use journalctl --utc for Logs view to handle DST 
- Fix testZoomSpeedControls scale selector

* Tue Nov 3 2020 Justin Stephenson <jstephen@redhat.com> - 6-1
- Release v6
- Bump testlib to 229
- Add binary recording test
- Update UI to adopt PatternFly 4
- Update dependencies
- Use --all journalctl option
- Fixed timezone issue by searching in client time
- Bump cockpit test version from 199 to 219
- Improve test coverage with more tests
- Simplify and cleanup existing tests

* Tue Jun 23 2020 Justin Stephenson <jstephen@redhat.com> - 4-2
- Release v4-2
- Fix testZoomControls test

* Wed May 27 2020 Justin Stephenson <jstephen@redhat.com> - 4-1
- Release v4
- Update parent id in metainfo file
- Update package manifest
- Fix rpmmacro to resolve correct path on CentOS7
- Handle byte-array encoded journal data
- Don't clobber cockpit bots directory
- Move code out of deprecated React lifecycle functions

* Mon Nov 25 2019 Justin Stephenson <jstephen@redhat.com> - 3-1
- Release v3
- Reset Logs View on Player Rewind
- Configuration page UI CSS Improvements

* Wed Sep 11 2019 Justin Stephenson <jstephen@redhat.com> - 2-1
- Release 2
- Optimize performance when playing back flooded output recordings.
- Make Logs View optional rendered with a toggle button.
- Make Logs component a child of Recording component.
- Fix Recording page column sorting in Google Chrome.
- CSS updates for Patternfly 4 compatibility.
- Replace term.js with maintained xterm.js library.
- Fix hostname and username filtering.

* Wed Jul 24 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu Apr 4 2019 Kirill Glebov <kgliebov@redhat.com> - 1-1
- Release 1
- First release. Includes logs correlation, player controls, journal remote support.
#
